@@ -36,9 +36,10 @@ impl Flood {
         bounds_builder: BoundsBuilder,
         ctx: &FilterContext,
         _acquired_nodes: &mut AcquiredNodes<'_>,
-        _draw_ctx: &mut DrawingCtx,
+        draw_ctx: &mut DrawingCtx,
     ) -> Result<FilterOutput, FilterError> {
         let bounds: IRect = bounds_builder.compute(ctx).clipped.into();
+        rsvg_log!(draw_ctx.session(), "(feFlood bounds={:?}", bounds);
 
         let surface = ctx.source_graphic().flood(bounds, self.color)?;
 
@@ -51,11 +52,11 @@ impl FilterEffect for FeFlood {
         &self,
         _acquired_nodes: &mut AcquiredNodes<'_>,
         node: &Node,
-    ) -> Result<ResolvedPrimitive, FilterResolveError> {
+    ) -> Result<Vec<ResolvedPrimitive>, FilterResolveError> {
         let cascaded = CascadedValues::new_from_node(node);
         let values = cascaded.get();
 
-        Ok(ResolvedPrimitive {
+        Ok(vec![ResolvedPrimitive {
             primitive: self.base.clone(),
             params: PrimitiveParams::Flood(Flood {
                 color: resolve_color(
@@ -64,6 +65,6 @@ impl FilterEffect for FeFlood {
                     values.color().0,
                 ),
             }),
-        })
+        }])
     }
 }
