@@ -76,6 +76,7 @@ impl Offset {
             .compute(ctx)
             .clipped
             .into();
+        rsvg_log!(draw_ctx.session(), "(feOffset bounds={:?}", bounds);
 
         let (dx, dy) = ctx.paffine().transform_distance(self.dx, self.dy);
 
@@ -90,10 +91,10 @@ impl FilterEffect for FeOffset {
         &self,
         _acquired_nodes: &mut AcquiredNodes<'_>,
         _node: &Node,
-    ) -> Result<ResolvedPrimitive, FilterResolveError> {
-        Ok(ResolvedPrimitive {
+    ) -> Result<Vec<ResolvedPrimitive>, FilterResolveError> {
+        Ok(vec![ResolvedPrimitive {
             primitive: self.base.clone(),
             params: PrimitiveParams::Offset(self.params.clone()),
-        })
+        }])
     }
 }
