@@ -8,8 +8,7 @@ use gio::{
 };
 use glib::Cast;
 use markup5ever::{
-    buffer_queue::BufferQueue, expanded_name, local_name, namespace_url, ns, ExpandedName,
-    LocalName, Namespace, QualName,
+    expanded_name, local_name, namespace_url, ns, ExpandedName, LocalName, Namespace, QualName,
 };
 use std::cell::RefCell;
 use std::collections::HashMap;
@@ -17,6 +16,7 @@ use std::rc::Rc;
 use std::str;
 use std::string::ToString;
 use std::sync::Arc;
+use xml5ever::buffer_queue::BufferQueue;
 use xml5ever::tendril::format_tendril;
 use xml5ever::tokenizer::{TagKind, Token, TokenSink, XmlTokenizer, XmlTokenizerOpts};
 
@@ -534,8 +534,7 @@ impl XmlState {
                 Some("text") => self.acquire_text(&aurl, encoding),
 
                 Some(v) => Err(AcquireError::FatalError(format!(
-                    "unknown 'parse' attribute value: \"{}\"",
-                    v
+                    "unknown 'parse' attribute value: \"{v}\""
                 ))),
             }
         } else {
@@ -557,19 +556,13 @@ impl XmlState {
         let encoding = encoding.unwrap_or("utf-8");
 
         let encoder = encoding_from_whatwg_label(encoding).ok_or_else(|| {
-            AcquireError::FatalError(format!(
-                "unknown encoding \"{}\" for \"{}\"",
-                encoding, aurl
-            ))
+            AcquireError::FatalError(format!("unknown encoding \"{encoding}\" for \"{aurl}\""))
         })?;
 
         let utf8_data = encoder
             .decode(&binary.data, DecoderTrap::Strict)
             .map_err(|e| {
-                AcquireError::FatalError(format!(
-                    "could not convert contents of \"{}\" from character encoding \"{}\": {}",
-                    aurl, encoding, e
-                ))
+                AcquireError::FatalError(format!("could not convert contents of \"{aurl}\" from character encoding \"{encoding}\": {e}"))
             })?;
 
         self.element_creation_characters(&utf8_data);
